]> sigrok.org Git - libsigrok.git/blobdiff - device.c
fx2lafw: Moved num_samples into context struct
[libsigrok.git] / device.c
index 5f8d5ed2a0f423cce66a4a1520b626ec81808fe4..3166ea8e0c087d72431ab7269d80e0308109c2cf 100644 (file)
--- a/device.c
+++ b/device.c
@@ -55,17 +55,17 @@ static GSList *devs = NULL;
  * TODO: Error checks?
  * TODO: Option to only scan for specific devices or device classes.
  *
* @return SR_OK upon success, SR_ERR upon errors.
  */
 SR_API int sr_dev_scan(void)
 {
        int i;
        struct sr_dev_driver **drivers;
 
-       drivers = sr_hw_list();
+       drivers = sr_driver_list();
        if (!drivers[0]) {
                sr_err("dev: %s: no supported hardware drivers", __func__);
-               return SR_ERR; /* TODO: More specific error? */
+               return SR_ERR_BUG;
        }
 
        /*
@@ -74,7 +74,7 @@ SR_API int sr_dev_scan(void)
         * of these out of the way first.
         */
        for (i = 0; drivers[i]; i++)
-               sr_hw_init(drivers[i]);
+               sr_driver_init(drivers[i]);
 
        return SR_OK;
 }
@@ -55,17 +55,17 @@ static GSList *devs = NULL;
  * TODO: Option to only scan for specific devices or device classes.
  *
- * @return SR_OK upon success, SR_ERR upon errors.
+ * @return SR_OK upon success, SR_ERR_BUG upon internal errors.
  */
 SR_API int sr_dev_scan(void)